# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.1.0] - 2024-12-07

### Added

* Allow schemata with flexibly selected parts.

### Changed

* Update static files.
* Update schemata for unit tests.

## [1.0.0] - 2024-09-14

### Added

* Initial release

Exported functions: load_datatype() and to_jsonld()

[unreleased]:
[1.0.0]: https://gitlab.com/TIBHannover/orkg/dtreg-python/-/tags/v1.0.0